    set seed 123456789
    set rmsg on
    clear mata
	drop _all
	run infection.mata
    
    // run a single model and graph the evolution of the infection over time
    mata
    foo = immune()
    foo.rdim(40)
    foo.cdim(40)
    foo.tdim(24)
    foo.radius(2)
    foo.not_vaccinated(240)
    foo.run()
    foo.extract(("id", "time", "status", "y", "x"))
    end
    
    replace y = - y

    mata st_local("rdim", strofreal(foo.rdim()))
    mata st_local("cdim", strofreal(foo.cdim()))
    mata st_local("tdim", strofreal(foo.tdim()))
    tempfile data
    save `data'
    drop _all
    set obs `rdim'
    gen x = _n
    expand `cdim'
    bys x : gen y = -_n
    expand `tdim' + 1
    bys y x : gen time = _n
    merge 1:1 x y time using `data'
    assert _merge != 2
    drop _merge
    
    forvalues t = 1/25 {
        scatter y x if status == 0 & time == `t' ,    ///
            msymbol(Oh)                            || ///
        scatter y x if status == 1 & time == `t' ,    ///
            msymbol(S) mcolor(gs8)                 || ///
        scatter y x if status == 2 & time == `t' ,    ///
            msymbol(S)                             || ///
        scatter y x if status == 3 & time == `t' ,    ///
            msymbol(+)                             || ///
        scatter y x if status == . & time == `t',     ///
            msymbol(o) msize(*.10) mcolor(gs8)        ///
            aspect(1) name(gr`t', replace)            ///
            yscale(off range(-41.5 -0.5))             ///
            xscale(off range(.5 41.5))                ///
            plotregion(margin(zero))                  ///
            title("Iteration `t'")                    /// 
            legend(order( 1 "vulnerable"              ///
                          2 "infected"                ///
                          3 "infectious"              ///
                          4 "healed/immunized"        ///
                          5 "immunized"))
    }
    
    // run multiple models and plot the seriousness of the infection against 
    // the immunization rate
    mata
    scen = (16, 80, 120, 160, 200, 240, 280, 320, 360, 400)
    res = J(200,2,.)
    k=0
    for (i = 1; i <= 10 ; i++) {
        printf("number of vulnerable: %3.0f \n", scen[i])
        foo.not_vaccinated(scen[i])
        for(j = 1; j<= 20; j++) {
            k = k +1
            foo.run()
            res[k,.] = scen[i], foo.n_infected()
        }
    }
    
    idx =  st_addvar("float", ("N","n"))
    st_addobs(200)
    st_store((1..200)',idx,res)
    end
    
    gen perc_notvac = N/(40*40)*100
    gen perc_inf    = n/N*100
    
    scatter perc_inf perc_notvac, msymbol(o) mcolor(%20) ///
        xtitle("percentage not vaccinated")              ///
        ytitle("percentage infected of not vacinated ")  ///
        name(scenarios, replace)
        
    